@@ -40,17 +40,19 @@
 
 static bool comparePlugins(const KService::Ptr &p1, const KService::Ptr &p2)
 {
-    return (p1->property("X-KDE-Priority").toInt()) > (p2->property("X-KDE-Priority").toInt());
+    return (p1->property(QLatin1String( "X-KDE-Priority" )).toInt()) > (p2->property(QLatin1String( "X-KDE-Priority" )).toInt());
 }
 
 static QString determineMimeType(const QString& filename)
 {
-    if (!QFile::exists(filename))
+    if (!QFile::exists(filename)) {
         return KMimeType::findByPath(filename)->name();
+    }
 
     QFile file(filename);
-    if (!file.open(QIODevice::ReadOnly))
+    if (!file.open(QIODevice::ReadOnly)) {
         return QString();
+    }
 
     const qint64 maxSize = 0x100000; // 1MB
     const qint64 bufferSize = qMin(maxSize, file.size());
@@ -66,7 +68,7 @@ static KService::List findPluginOffers(const QString& filename, const QString& f
     const QString mimeType = fixedMimeType.isEmpty() ? determineMimeType(filename) : fixedMimeType;
 
     if (!mimeType.isEmpty()) {
-        offers = KMimeTypeTrader::self()->query(mimeType, "Kerfuffle/Plugin", "(exist Library)");
+        offers = KMimeTypeTrader::self()->query(mimeType, QLatin1String( "Kerfuffle/Plugin" ), QLatin1String( "(exist Library)" ));
         qSort(offers.begin(), offers.end(), comparePlugins);
     }
 
@@ -110,7 +112,7 @@ Archive *factory(const QString& filename, const QString& fixedMimeType)
 
 QStringList supportedMimeTypes()
 {
-    const QString constraint("(exist Library)");
+    const QLatin1String constraint("(exist Library)");
     const QLatin1String basePartService("Kerfuffle/Plugin");
 
     const KService::List offers = KServiceTypeTrader::self()->query(basePartService, constraint);
@@ -137,7 +139,7 @@ QStringList supportedMimeTypes()
 
 QStringList supportedWriteMimeTypes()
 {
-    const QString constraint("(exist Library) and ([X-KDE-Kerfuffle-ReadWrite] == true)");
+    const QLatin1String constraint("(exist Library) and ([X-KDE-Kerfuffle-ReadWrite] == true)");
     const QLatin1String basePartService("Kerfuffle/Plugin");
 
     const KService::List offers = KServiceTypeTrader::self()->query(basePartService, constraint);
