@@ -37,11 +37,12 @@
 #include <khtml_part.h>
 
 #include <QHBoxLayout>
+#include <QFile>
 #include <QFrame>
 #include <QLabel>
 
 ArkViewer::ArkViewer(QWidget * parent, Qt::WFlags flags)
-        : KDialog(parent, flags), m_part(0)
+        : KDialog(parent, flags)
 {
     setButtons(Close);
     m_widget = new KVBox(this);
@@ -68,17 +69,33 @@ void ArkViewer::dialogClosed()
         progressDialog.setAllowCancel(false);
         progressDialog.progressBar()->setRange(0, 0);
 
-        m_part->closeUrl();
+        // #261785: this preview dialog is not modal, so we need to delete
+        //          the previewed file ourselves when the dialog is closed;
+        //          we used to remove it at the end of ArkViewer::view() when
+        //          QDialog::exec() was called instead of QDialog::show().
+        const QString previewedFilePath(m_part.data()->url().pathOrUrl());
+
+        m_part.data()->closeUrl();
+
+        if (!previewedFilePath.isEmpty()) {
+            QFile::remove(previewedFilePath);
+        }
     }
 }
 
+// TODO: We call QFile::remove() in many different places here (#261785), which
+//       is very error-prone.
+//       In the future, we could make this method non-static and try to
+//       centralize the call to QFile::remove().
 void ArkViewer::view(const QString& filename, QWidget *parent)
 {
     KService::Ptr viewer = ArkViewer::getViewer(filename);
 
     if (viewer.isNull()) {
         KMessageBox::sorry(parent, i18n("The internal viewer cannot preview this file."));
-    } else if (viewer->hasServiceType("KParts/ReadOnlyPart")) {
+
+        QFile::remove(filename);
+    } else if (viewer->hasServiceType(QLatin1String( "KParts/ReadOnlyPart" ))) {
         ArkViewer *internalViewer = new ArkViewer(parent, Qt::Window);
 
         internalViewer->hide();
@@ -86,19 +103,17 @@ void ArkViewer::view(const QString& filename, QWidget *parent)
         if (!internalViewer->viewInInternalViewer(filename)) {
             KMessageBox::sorry(parent, i18n("The internal viewer cannot preview this file."));
             delete internalViewer;
+
+            QFile::remove(filename);
+
             return;
         }
 
         internalViewer->show();
     } else { // Try to open it in an external application
         KUrl fileUrl(filename);
-        KRun::runUrl(fileUrl, KMimeType::findByUrl(fileUrl, 0, true)->name(), parent);
-        return;
+        KRun::runUrl(fileUrl, KMimeType::findByUrl(fileUrl, 0, true)->name(), parent, true);
     }
-
-    // Unlink the temp file (not used by the external viewer since KRun will do that for us at
-    // the right moment
-    KIO::NetAccess::del(KUrl(filename), parent);
 }
 
 void ArkViewer::keyPressEvent(QKeyEvent *event)
@@ -107,8 +122,9 @@ void ArkViewer::keyPressEvent(QKeyEvent *event)
 
     // Only handle the event the usual way if the default button has focus
     // Otherwise, pressing enter on KatePart still closes the dialog, for example.
-    if ((defButton) && (defButton->hasFocus()))
+    if ((defButton) && (defButton->hasFocus())) {
         KDialog::keyPressEvent(event);
+    }
 
     event->accept();
 }
@@ -122,8 +138,9 @@ bool ArkViewer::viewInInternalViewer(const QString& filename)
     setCaption(fileUrl.fileName());
     // TODO: Load the size from the config file
     QSize size = QSize();
-    if (size.width() < 200)
+    if (size.width() < 200) {
         size = QSize(560, 400);
+    }
     setInitialSize(size);
 
     QFrame *header = new QFrame(m_widget);
@@ -136,7 +153,7 @@ bool ArkViewer::viewInInternalViewer(const QString& filename)
 
     KVBox *headerRight = new KVBox(header);
     headerLayout->addWidget(headerRight);
-    new QLabel(QString("<qt><b>%1</b></qt>")
+    new QLabel(QString(QLatin1String( "<qt><b>%1</b></qt>" ))
                .arg(fileUrl.fileName()), headerRight
               );
     new QLabel(mimetype->comment(), headerRight);
@@ -147,12 +164,12 @@ bool ArkViewer::viewInInternalViewer(const QString& filename)
              m_widget,
              this);
 
-    if (!m_part) {
+    if (!m_part.data()) {
         return false;
     }
 
-    if (m_part->browserExtension()) {
-        connect(m_part->browserExtension(),
+    if (m_part.data()->browserExtension()) {
+        connect(m_part.data()->browserExtension(),
                 SIGNAL(openUrlRequestDelayed(KUrl, KParts::OpenUrlArguments, KParts::BrowserArguments)),
                 SLOT(slotOpenUrlRequestDelayed(KUrl, KParts::OpenUrlArguments, KParts::BrowserArguments)));
     }
@@ -160,7 +177,7 @@ bool ArkViewer::viewInInternalViewer(const QString& filename)
     // #235546
     // TODO: the user should be warned in a non-intrusive way that some features are going to be disabled
     //       maybe there should be an option controlling this
-    KHTMLPart *khtmlPart = qobject_cast<KHTMLPart*>(m_part);
+    KHTMLPart *khtmlPart = qobject_cast<KHTMLPart*>(m_part.data());
     if (khtmlPart) {
         kDebug() << "Disabling javascripts, plugins, java and external references for KHTMLPart";
         khtmlPart->setJScriptEnabled(false);
@@ -170,7 +187,7 @@ bool ArkViewer::viewInInternalViewer(const QString& filename)
         khtmlPart->setOnlyLocalReferences(true);
     }
 
-    m_part->openUrl(fileUrl);
+    m_part.data()->openUrl(fileUrl);
 
     return true;
 }
