@@ -88,8 +88,11 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList& args)
     m_splitter = new QSplitter(Qt::Horizontal, parentWidget);
     setWidget(m_splitter);
 
-    m_view = new ArchiveView(m_splitter);
-    m_infoPanel = new InfoPanel(m_model, m_splitter);
+    m_view = new ArchiveView;
+    m_infoPanel = new InfoPanel(m_model);
+
+    m_splitter->addWidget(m_view);
+    m_splitter->addWidget(m_infoPanel);
 
     QList<int> splitterSizes = ArkSettings::splitterSizes();
     if (splitterSizes.isEmpty()) {
@@ -148,6 +151,9 @@ void Part::registerJob(KJob* job)
     connect(job, SIGNAL(result(KJob*)), this, SIGNAL(ready()));
 }
 
+// TODO: One should construct a KUrl out of localPath in order to be able to handle
+//       non-local destinations (ie. trash:/ or a remote location)
+//       See bugs #189322 and #204323.
 void Part::extractSelectedFilesTo(const QString& localPath)
 {
     kDebug() << "Extract to " << localPath;
@@ -749,7 +755,20 @@ void Part::slotAddFiles(const QStringList& filesToAdd, const QString& path)
 void Part::slotAddFiles()
 {
     kDebug();
-    const QStringList filesToAdd = KFileDialog::getOpenFileNames(KUrl("kfiledialog:///ArkAddFiles"), QString(), widget(), i18nc("@title:window", "Add Files"));
+
+    // #264819: passing widget() as the parent will not work as expected.
+    //          KFileDialog will create a KFileWidget, which runs an internal
+    //          event loop to stat the given directory. This, in turn, leads to
+    //          events being delivered to widget(), which is a QSplitter, which
+    //          in turn reimplements childEvent() and will end up calling
+    //          QWidget::show() on the KFileDialog (thus showing it in a
+    //          non-modal state).
+    //          When KFileDialog::exec() is called, the widget is already shown
+    //          and nothing happens.
+    const QStringList filesToAdd =
+        KFileDialog::getOpenFileNames(KUrl("kfiledialog:///ArkAddFiles"),
+                                      QString(), widget()->parentWidget(),
+                                      i18nc("@title:window", "Add Files"));
 
     slotAddFiles(filesToAdd);
 }
