@@ -23,23 +23,25 @@
 #ifndef PART_H
 #define PART_H
 
+#include "interface.h"
+
 #include <KParts/Part>
 #include <KParts/StatusBarExtension>
+
 #include <QModelIndex>
-#include "interface.h"
 
 class ArchiveModel;
 class InfoPanel;
 
+class KAbstractWidgetJobTracker;
+class KAboutData;
+class KAction;
+class KJob;
+class KTempDir;
+
+class QAction;
 class QSplitter;
 class QTreeView;
-class QAction;
-class KAction;
-
-class KAboutData;
-class KTempDir;
-class KJob;
-class KAbstractWidgetJobTracker;
 
 namespace Ark
 {
@@ -90,13 +92,14 @@ private slots:
 signals:
     void busy();
     void ready();
+    void quit();
 
 private:
     void setupView();
     void setupActions();
-    bool isSingleFolderArchive();
-    QString detectSubfolder();
-    bool isPreviewable(const QModelIndex & index);
+    bool isSingleFolderArchive() const;
+    QString detectSubfolder() const;
+    bool isPreviewable(const QModelIndex& index) const;
     QList<QVariant> selectedFiles();
     QList<QVariant> selectedFilesWithChildren();
     void registerJob(KJob *job);
