@@ -637,7 +637,7 @@ PyObject* py_hide(PyObject *, PyObject *args)
 #include <sys/ioctl.h>
 #include <net/if.h>
 #include <arpa/inet.h>
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__DragonFly__)
 #include <netinet/in.h>
 #endif
 #ifdef __OpenBSD__
